npstructures.RaggedArray
========================

.. currentmodule:: npstructures

.. autoclass:: RaggedArray

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RaggedArray.__init__
      ~RaggedArray.all
      ~RaggedArray.equals
      ~RaggedArray.load
      ~RaggedArray.mean
      ~RaggedArray.nonzero
      ~RaggedArray.ravel
      ~RaggedArray.save
      ~RaggedArray.sum
      ~RaggedArray.tolist
   
   

   
   
   